@@ -14,7 +14,10 @@ use crate::task::spawn;
 pub struct ListenService {
     #[derivative(Debug = "ignore")]
     pub(crate) callback: Arc<
-        dyn Fn(Vec<u8>) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, CallError>> + Send>>
+        dyn Fn(
+                CallHandle,
+                Vec<u8>,
+            ) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, CallError>> + Send>>
             + Send
             + Sync,
     >,
@@ -23,7 +26,11 @@ pub struct ListenService {
 impl ListenService {
     pub fn new(
         callback: Arc<
-            dyn Fn(Vec<u8>) -> Pin<Box<dyn Future<Output = Result<Vec<u8>, CallError>> + Send>>
+            dyn Fn(
+                    CallHandle,
+                    Vec<u8>,
+                )
+                    -> Pin<Box<dyn Future<Output = Result<Vec<u8>, CallError>> + Send>>
                 + Send
                 + Sync,
         >,
@@ -34,7 +41,7 @@ impl ListenService {
     pub fn process(&self, handle: CallHandle, request: Vec<u8>) {
         let callback = Arc::clone(&self.callback);
         spawn(async move {
-            let res = callback.as_ref()(request);
+            let res = callback.as_ref()(handle, request);
             match res.await {
                 Ok(a) => {
                     crate::abi::syscall::reply(handle, &a[..]);
@@ -44,6 +51,7 @@ impl ListenService {
                     crate::abi::syscall::fault(handle, err as u32);
                 }
             }
+            crate::engine::BusEngine::remove(&handle);
         });
     }
 }
