@@ -2,4 +2,4 @@ mod runtime;
 mod waker;
 
 pub use runtime::*;
-use waker::*;
+pub use waker::*;
